@@ -83,9 +83,9 @@ est.projection.TSdata <- function(data, center=TRUE, scale=TRUE, m=1,p=1)
   # otherwise use canonical correlation.
   data <- freeze(data)
   conc <- list()
-  if ((0!= input.dimension(data)) & (0!=output.dimension(data)))
-    {if (input.dimension(data) < m) stop("m cannot exceed input data dimension.")
-     if (output.dimension(data)< p) stop("p cannot exceed output data dimension.")
+  if ((0!= nseriesInput(data)) & (0!=nseriesOutput(data)))
+    {if (nseriesInput(data) < m) stop("m cannot exceed input data dimension.")
+     if (nseriesOutput(data)< p) stop("p cannot exceed output data dimension.")
      cc <- cancorrelation(input.data(data), output.data(data),
                   xcenter=center, ycenter=center, xscale=scale, yscale=scale)
      conc$input$proj    <- cc$xcoef[ , 1:m, drop=FALSE] 
@@ -97,12 +97,12 @@ est.projection.TSdata <- function(data, center=TRUE, scale=TRUE, m=1,p=1)
      conc$output$scale  <- cc$yscale
      dseclass(conc$output) <- "concentrator" # constructor
     }
-  else if (0!= input.dimension(data))
-    {if (input.dimension(data) < m) stop("m cannot exceed input data dimension.")
+  else if (0!= nseriesInput(data))
+    {if (nseriesInput(data) < m) stop("m cannot exceed input data dimension.")
      conc$input <- est.projection( input.data(data),center=center, scale=scale, n=m)
     }
-  else if (0!=output.dimension(data))
-    {if (output.dimension(data) < p) stop("p cannot exceed output data dimension.")
+  else if (0!=nseriesOutput(data))
+    {if (nseriesOutput(data) < p) stop("p cannot exceed output data dimension.")
      conc$output<- est.projection(output.data(data),center=center, scale=scale, n=p)
     }
   classed(conc, "TSdataconcentrator") # constructor
@@ -133,9 +133,9 @@ concentrate.TSdata <- function(d, center=TRUE, scale=TRUE,  m=1, p=1, conc=NULL)
   d <- freeze(d)
   if (is.null(conc)) conc <- est.projection(d, center=center, scale=scale, m=m, p=p)
   else conc <- concentrator(conc)
-  if (0!= input.dimension(d))
+  if (0!= nseriesInput(d))
       input.data(d) <- concentrate(input.data(d), conc=conc$input)
-  if (0!=output.dimension(d))
+  if (0!=nseriesOutput(d))
      output.data(d) <- concentrate(output.data(d), conc=conc$output)
   classed(d, c("TSdataconcentrate", "TSdata")) # constructor (concentrate.TSdata)
  }
@@ -160,12 +160,14 @@ concentrateOnly.concentrate <- function(d)
  {#return concentrate (as simple data) with original and concentrator removed
   conc <- concentrator(d)
   newd <-  sweep(sweep(d,2, conc$center), 2, conc$scale, FUN="/") %*% conc$proj
-  tframe(newd) <- tframe(d)
-#  series.names(newd) <- paste("concentrate", seq(ncol(d)))
-  series.names(newd) <- concentrated.series.names(d)
+  tframe(newd) <- tframe(d) # newd will not (necessarily) have the class of d
+#  seriesNames(newd) <- paste("concentrate", seq(ncol(d)))
+  seriesNames(newd) <- concentrated.seriesNames(d)
   attr(newd, "concentrator") <- conc
   attr(newd, "original") <- NULL
-  classed(newd, dseclass(d)[-1])  # deconstructor
+#  classed(newd, dseclass(d)[-1])  # newd may not have correct structure for
+#                                    this (e.g. tsp attr for a ts)
+  newd
  } 
  
 concentrateOnly.TSdataconcentrate <- function(d) 
@@ -241,7 +243,7 @@ reconstitute <- function(d, conc=NULL, names=NULL) {UseMethod("reconstitute")}
 
 TSdata.TSdataconcentrate <- reconstitute 
 
-reconstitute.default <- function(d, conc, names=series.names(d))
+reconstitute.default <- function(d, conc, names=seriesNames(d))
  {# this actually concentrates the data and then reconstitutes it.
   conc <- concentrator(conc)
   inv <- svd(conc$proj) 
@@ -249,14 +251,14 @@ reconstitute.default <- function(d, conc, names=series.names(d))
   newd <- newd %*% inv$v %*% sweep(t(inv$u), 1, 1/inv$d, "*")
   newd <-  sweep(sweep(newd,2, conc$scale, FUN="*"),2, -conc$center)
   tframe(newd) <- tframe(d)
-  if (!is.null(names)) series.names(newd) <- paste("recon.", names)
+  if (!is.null(names)) seriesNames(newd) <- paste("recon.", names)
   attr(newd, "concentrator") <- conc
   classed(newd, c("reconstitute", dseclass(d))) #constructor reconstitute.default
  }
   
 
 reconstitute.concentrate <- function(d, conc=concentrator(d),
-                                    names=series.names(d))
+                                    names=seriesNames(d))
  {# d as returned by concentrate.
   newd <- reconstitute.default(concentrateOnly(d), conc=conc, names=names)
   attr(newd, "original") <- concentrateOriginal(d)
@@ -264,13 +266,13 @@ reconstitute.concentrate <- function(d, conc=concentrator(d),
  }
 
 reconstitute.TSdataconcentrate <- function(d, conc=concentrator(d),
-                                    names=series.names(d))
+                                    names=seriesNames(d))
  {# d as returned by concentrate. A different conc (proj) can be used.
   # don't use input.data(d) or input.data(concentrateOnly(d)) here as they both
   # obscure the fact that d is concentrate. ??but so what ? this comment may be old
-  if (0!= input.dimension(d))
+  if (0!= nseriesInput(d))
     input.data(d) <- reconstitute(d$input, conc$input, names=names$input) 
-  if (0!=output.dimension(d)) 
+  if (0!=nseriesOutput(d)) 
    output.data(d) <- reconstitute(d$output, conc$output,names=names$output)
   classed(d, c("TSdatareconstitute", "TSdata"))# constructor reconstitute.TSdataconcentrate)
  }
@@ -280,22 +282,22 @@ is.TSdatareconstitute <- function(x) {inherits(x, "TSdatareconstitute")}
 
 
 canonical.prediction <- function(d, conc=concentrator(d),
-      q=min(concentrated.input.dimension(d), concentrated.output.dimension(d)))
+      q=min(concentrated.nseriesInput(d), concentrated.nseriesOutput(d)))
  {if (all(q == 0))
     stop("Both input and output data must exist for canonical.prediction.")
   if (max(q) >
-      min(concentrated.input.dimension(d), concentrated.output.dimension(d)))
+      min(concentrated.nseriesInput(d), concentrated.nseriesOutput(d)))
      stop(paste("number of canonical coordinates cannot exceed min. of input and output canonical components (",
-    min(concentrated.input.dimension(d), concentrated.output.dimension(d)),")"))
+    min(concentrated.nseriesInput(d), concentrated.nseriesOutput(d)),")"))
   prj <- conc$output
   if (1 == length(q)) q <- seq(q)
-  if (all(q != seq(concentrated.output.dimension(d))))
+  if (all(q != seq(concentrated.nseriesOutput(d))))
     {prj$u <- prj$u[ , q, drop=FALSE]
      prj$v <- prj$v[q,  , drop=FALSE] 
      prj$d <- prj$d[q]
     }
-  pred <- reconstitute(input.data(concentrateOnly(d))[,q], prj,
-                           names=output.series.names(concentrateOriginal(d)))
+  pred <- reconstitute(input.data(concentrateOnly(d), series=q), prj,
+                           names=seriesNamesOutput(concentrateOriginal(d)))
   attr(pred, "original") <- output.data(concentrateOriginal(d))
   classed(pred, "TScanonical.prediction") #constructor (canonical.prediction)
  }
@@ -310,7 +312,7 @@ tfplot.TScanonical.prediction <- function(x, xlab=NULL, ylab=NULL,
 	 series=seq(nseries(x)), mar=par()$mar)
 {# plot actual data and data reconstituted from canonical.prediction.
  z <- concentrateOriginal(x)
- series.names(z) <- series.names(x) # used on plot
+ seriesNames(z) <- seriesNames(x) # used on plot
  tfplot(z, x, xlab=xlab, ylab=ylab, graphs.per.page=graphs.per.page, 
          start.=start., end.=end., series=series, mar=mar)
  invisible()
@@ -360,7 +362,7 @@ est.concentrated.model.TSdataconcentrate <- function(data,
 # next should be   concentrator(m) <- concentrator(data)
    m$conc <- concentrator(data)
    dseclass(m) <- c("TSmodelconcentrate", dseclass(m))
-   series.names(m) <- series.names(data)
+   seriesNames(m) <- seriesNames(data)
    l(m, data, warn=warn)
   }
 
@@ -375,7 +377,7 @@ l.TSmodelconcentrate <- function(model,data, sampleT=nrow(output.data(data)),
    pred  <- l(concentrateOnly(model), concentrateOnly(data),
               sampleT=sampleT, predictT=predictT)$estimates$pred
    pred  <- reconstitute(pred, concentrator(data)$output,
-        names=output.series.names(data))
+        names=seriesNamesOutput(data))
 
    if((!is.null(result)) && (result == "pred")) return(pred)
    r <- residual.stats(pred, output.data(concentrateOriginal(data)),
@@ -393,12 +395,12 @@ check.consistent.dimensions.TSmodelconcentrate <- function(model, data=NULL)
   {m <- classed(model, dseclass(model)[-1]) # deconstructor 
    check.consistent.dimensions(m)
    if(!is.null(data))
-       {if(output.dimension(model) != output.dimension(data))
+       {if(nseriesOutput(model) != nseriesOutput(data))
 	    stop("Model and data output dimensions do not correspond.")
-        if( input.dimension(model) != input.dimension(data))
+        if( nseriesInput(model) != nseriesInput(data))
 	    stop("Model and data input dimensions do not correspond.")
        }
-   return(T)
+   return(TRUE)
   }
 
      
@@ -412,9 +414,9 @@ check.consistent.dimensions.TSmodelconcentrate <- function(model, data=NULL)
 
 
 
-input.dimension.TSmodelconcentrate <- function(x)
+nseriesInput.TSmodelconcentrate <- function(x)
      {d <-nrow(concentrator(x)$input$proj);  if(is.null(d)) 0 else d}
-output.dimension.TSmodelconcentrate <- function(x)
+nseriesOutput.TSmodelconcentrate <- function(x)
      {d <-nrow(concentrator(x)$output$proj); if(is.null(d)) 0 else d}
 
 
@@ -425,35 +427,46 @@ concentrated.dimension.concentrate <- function(x) {ncol(concentrator(x)$proj)}
 
 
 
-concentrated.input.dimension <- function(x) {concentrated.dimension(x$input)}
-concentrated.output.dimension <- function(x) {concentrated.dimension(x$output)}
+concentrated.nseriesInput <- function(x) {concentrated.dimension(x$input)}
+concentrated.nseriesOutput <- function(x) {concentrated.dimension(x$output)}
 
 
 
-concentrated.series.names <- function(x){UseMethod("concentrated.series.names")}
+concentrated.seriesNames <- function(x){UseMethod("concentrated.seriesNames")}
    
-concentrated.series.names.concentrate <- function(x)
+concentrated.seriesNames.concentrate <- function(x)
   { paste("concentrate", seq(concentrated.dimension(x))) }
 
-concentrated.series.names.TSdata <- function(x)
-   {list(input = concentrated.input.series.names(x),
-        output = concentrated.output.series.names(x)) }
+concentrated.seriesNames.TSdata <- function(x)
+   {list(input = concentrated.seriesNamesInput(x),
+        output = concentrated.seriesNamesOutput(x)) }
 
-concentrated.input.series.names <- function(x)
- {if(is.null(x$input)) NULL else concentrated.series.names(x$input)}
+concentrated.seriesNamesInput <- function(x)
+ {if(is.null(x$input)) NULL else concentrated.seriesNames(x$input)}
 
-concentrated.output.series.names <- function(x)
- {if(is.null(x$output)) NULL else concentrated.series.names(x$output)}
+concentrated.seriesNamesOutput <- function(x)
+ {if(is.null(x$output)) NULL else concentrated.seriesNames(x$output)}
 
 
-
-
-settf.concentrate <- function(value, x)
- {# this would not be necessary if tframe inheritence was more cleanly 
-  # separated from classes of x. See "pure" comments in settf.default
+"tframe<-.concentrate" <- function(x, value){
   cls <- dseclass(x)
-  classed(x, settf(value, classed(x, cls[-1])), cls)
- }
+  x <- classed(x, cls[-1])
+  tframe(x) <- value 
+  # may not have class back the way it should be ???  
+  classed(x, cls)
+}
+
+tframed.concentrate <- function(x, tf=NULL, names = NULL) 
+{cls <- dseclass(x)
+ classed(tframed(classed(x, cls[-1]), tf=tf, names=names), cls)
+}
+
+#settf.concentrate <- function(value, x)
+# {# this would not be necessary if tframe inheritence was more cleanly 
+#  # separated from classes of x. See "pure" comments in settf.default
+#  cls <- dseclass(x)
+#  classed(x, settf(value, classed(x, cls[-1])), cls)
+# }
 
 
 tfprint.concentrate <- function(x, ...)
@@ -479,7 +492,7 @@ select.series.concentrate <-function (x, series = seq(nrow(concentrator(x)$proj)
   orig <- select.series(concentrateOriginal(x), series=series)
   # look at select.series.default to get series right
   conc$sdev <- conc$sdev[series]
-  conc$proj <- conc$proj[series,,drop=F]
+  conc$proj <- conc$proj[series,,drop=FALSE]
   conc$center <- conc$center[series]
   conc$scale <- conc$scale[series]
   attr(x, "concentrator") <- conc  
@@ -505,9 +518,9 @@ tfplot.concentrate <- function(x, xlab=NULL, ylab=NULL,
 }
 
 tfplot.TSdataconcentrate <- function(x, start. = NULL, end. = NULL,
-    Title = "", reset.screen = T, 
-    select.inputs  = seq(length = input.dimension(x)),
-    select.outputs = seq(length = output.dimension(x)), 
+    Title = "", reset.screen = TRUE, 
+    select.inputs  = seq(length = nseriesInput(x)),
+    select.outputs = seq(length = nseriesOutput(x)), 
     graphs.per.page = 5, ylab = NULL, mar=par()$mar)
 {# plot actual data and data reconstituted from concentrate.
  tfplot.TSdata(concentrateOriginal(x), reconstitute(x), start.=start.,end.=end., 
@@ -532,7 +545,7 @@ tfplot.TSdatareconstitute <- function(x, ...)
 plot2by2 <- function(data, ...) {UseMethod("plot2by2")}
 
 plot2by2.TSdata <- function(data, ...)
-  {if (0==input.dimension(data)) plot2by2(output.data(data))
+  {if (0==nseriesInput(data)) plot2by2(output.data(data))
    else  plot2by2(tbind(input.data(data), output.data(data)))
   }
 
