@@ -7,6 +7,8 @@
 #     home in frame 0. (I'll never do that again.)
 #   if (is.S()) remove("DSE.HOME", where=0) 
 
+  Sys.sleep(15) # just in case a previous server has not yet died
+
 
  Sys.info()
  version.dse()
@@ -18,7 +20,6 @@
  cat("PADI_CLEANUP set to ", Sys.getenv("PADI_CLEANUP"), "\n")
  cat("user name set to ", Sys.info()[["user"]], "\n")
 
-   require("padi")
    if (is.S()) {
 	# the next 2 lines remove old versions of PADI in the search path
  	invisible(if(0!=length(grep("b*/PADI/.Data",search())))
@@ -41,12 +42,14 @@
 
 ###########################################################################
 
+if ( ! require("padi") ) warning("Warning: package padi is needed.") else {
 
-simple.monitor.function.tests <- function( verbose=T, synopsis=T, 
-         fuzz.small=1e-14, fuzz.large=1e-8,
-         server.process = PADIserverProcess(),
-         cleanup.script = PADIcleanupScript() )
-{# Some of the tests here are really for functions defined in dse1 ... dse3
+fuzz.small <- 1e-14
+fuzz.large <- 1e-8
+server.process <- PADIserverProcess()
+cleanup.script <- PADIcleanupScript()
+	 
+ # Some of the tests here are really for functions defined in dse1 ... dse3
  #   but are not tested there to avoid assuming TSPADI (or Fame) access is
  # available. The main short coming of these tests is that they do not test
  #     functions which produce output or graphs.
@@ -61,15 +64,16 @@ simple.monitor.function.tests <- function( verbose=T, synopsis=T,
   server <- Sys.info()[["nodename"]]
   db     <- paste(DSE.HOME,"/data/monitoring.test.db",sep="")
 
-  if (synopsis & !verbose) cat("All simple monitor tests ...")
   all.ok <- T
 
-  if (verbose) cat("simple monitor test 0 ... ")
+  cat("simple monitor test 0 ...\n")
   # simulate a database server
   pid <- startPADIserver(server=server,
            dbname=db, 
            server.process=server.process)
-  on.exit(cleanupPADIserver(pid, cleanup.script=cleanup.script))
+	   
+#next was used when this test was a function, but now moved to end of test script	   
+#  on.exit(cleanupPADIserver(pid, cleanup.script=cleanup.script))
 
   # wait for server to start 
      for (i in 1:30)
@@ -78,49 +82,50 @@ simple.monitor.function.tests <- function( verbose=T, synopsis=T,
        }
   ok <- T
   all.ok <- all.ok & ok 
-  if (verbose)  {if (ok) cat("ok\n") else  cat("failed!\n") }
+   {if (ok) cat("ok\n") else  cat("failed!\n") }
 
 
-  if (verbose) cat("simple monitor test 1 ... ")
+  cat("simple monitor test 1 ...\n")
   #  db=db would not be nec. with a public mode fame server   
   test.data.names <- TSPADIdata(
       input  ="B14017", 
       output = c( "P484549", "I37026", "lfsa201","b3400"), 
-      server=server, db=db, pad.end =T)
+      server=server, db=db, pad.end =T,
+      start.server=FALSE)
    
-  z <-availability(test.data.names, verbose=F) 
+  z <-availability(test.data.names, verbose=T) 
   ok <- all(c(z$start == t(matrix(c(1974,2),2,5)), 
               z$end   == t(matrix(c(1993,9),2,5)), 
               z$freq==rep(12,5) ))
   all.ok <- all.ok & ok 
-  if (verbose)  {if (ok) cat("ok\n") else  cat("failed!\n") }
+   {if (ok) cat("ok\n") else  cat("failed!\n") }
 
 
 # the following sets ets.test.data, monitor.test.data, verification.data
 #      and  monitoring.test
   source(paste(DSE.HOME,"/data/monitoring.test.info", sep=""))
 
-  if (verbose) cat("simple monitor test 2 ... ") 
+  cat("simple monitor test 2 ...\n") 
   v.data <- verification.data
   output.data(v.data) <- output.data(v.data)[,c(1,2,6,7)]
   tframe(output.data(v.data)) <- tframe(output.data(verification.data))
   ok <- is.TSdata(v.data)
   all.ok <- all.ok & ok 
-  if (verbose)  {if (ok) cat("ok\n") else  cat("failed!\n") }
+   {if (ok) cat("ok\n") else  cat("failed!\n") }
 
-  if (verbose) cat("simple monitor test 3 ... ")
+  cat("simple monitor test 3 ...\n")
   hist.data <-retrieve.and.verify.data(test.data.names, 
                                     verification.data=v.data)
   ok <- test.equal(hist.data, ets.test.data, fuzz=fuzz.small)
   all.ok <- all.ok & ok 
-  if (verbose)  {if (ok) cat("ok\n") else  cat("failed!\n") }
+   {if (ok) cat("ok\n") else  cat("failed!\n") }
 
 
-  if (verbose) cat("simple monitor test 4 ... ")
+  cat("simple monitor test 4 ...\n")
   monitoring<-simple.monitoring (monitoring.test.model, test.data.names, 
         previous.data=NULL, mail.list=Sys.info()[["user"]], error.mail.list=Sys.info()[["user"]]) 
   ok <-  monitoring$status == "Simple monitoring initialized."   
-  if (verbose) cat("\n This test produces a warning: Input is not longer than output data. No forecasts produced...")
+  cat("\n This test produces a warning: Input is not longer than output data. No forecasts produced...")
   # note that the following does not result in forecasts (and the forecast
   #   function produces a warning) because the input data does not extend
   #   beyond the output data.
@@ -143,10 +148,10 @@ simple.monitor.function.tests <- function( verbose=T, synopsis=T,
   ok <- ok & (monitoring$status == "Simple monitoring updated.") &
       sum(output.data(monitoring$data)) == 235.64806565791809589
   all.ok <- all.ok & ok 
-  if (verbose)  {if (ok) cat("ok\n") else  cat("failed!\n") }
+   {if (ok) cat("ok\n") else  cat("failed!\n") }
 
 
-  if (verbose) cat("simple monitor test 5 ... ")
+  cat("simple monitor test 5 ...\n")
 
   watch <- watch.data(test.data.names, previous.data=NULL, mail.list=Sys.info()[["user"]])
   ok <- (watch$status == "System watch.data initialized.") & 
@@ -156,23 +161,27 @@ simple.monitor.function.tests <- function( verbose=T, synopsis=T,
            sum(input.data(watch$data))== -4.1300000572204575988
   watch$data <- tfwindow(watch$data, end=c(1993, 8))
   watch <- watch.data(test.data.names, previous.data=watch, mail.list=Sys.info()[["user"]])
-  ok <- ok & (watch$status == "Data has been updated.") & 
-          sum(output.data(watch$data))== 235.64806565791809589
+  ok <- ok & (watch$status == "Data has been updated.")  
+  if (ok) cat("ok\n") else  cat("failed!\n") 
 
   all.ok <- all.ok & ok 
-  if (verbose)  {if (ok) cat("ok\n") else  cat("failed!\n") }
+  tst <-  sum(output.data(watch$data))
+  good <- 235.64806565791809589
 
-  if (synopsis) 
-    {if (verbose) cat("All simple monitor tests completed")
-     if (all.ok) cat(" OK\n\n") else    cat(", some FAILED!\n\n")
-    }
+   error <- max(abs(good - tst))
+   cat("max. error ", max(error), "\n")
+   
+   if (any(is.na(error)) || any(is.nan(error)) || fuzz.small < error) 
+     {if (any(is.na(error)))  cat("na's: ",  is.na(error), "\n")
+      if (any(is.nan(error))) cat("nan's: ", is.nan(error), "\n")
+      if (fuzz.small < error) cat("error: ", error, "\n")
+      print.test.value(c(tst), digits=18)
+      all.ok <- F  
+     }
+
+
+cleanupPADIserver(pid, cleanup.script=cleanup.script)
+
+if (!all.ok) stop("Simpmon tests FAILED")
 
-  if (all.ok) invisible(T)  else stop("FAILED")
 }
-
-
-  Sys.sleep(15) # just in case a previous server has not yet died
-
-if ( ! require("padi") ) warning("Warning: package padi is needed.") else
-   simple.monitor.function.tests(verbose=T) 
-
